# DataLakeStore

> see https://aka.ms/autorest

This is the AutoRest configuration file for DataLakeStore.



---
## Getting Started
To build the SDK for DataLakeStore, simply [Install AutoRest](https://aka.ms/autorest/install) and in this folder, run:

> `autorest`

To see additional help and options, run:

> `autorest --help`
---

## Configuration



### Basic Information
These are the global settings for the DataLakeStore API.

``` yaml
openapi-type: arm
tag: package-2016-11
```


### Tag: package-2016-11

These settings apply only when `--tag=package-2016-11` is specified on the command line.

``` yaml $(tag) == 'package-2016-11'
input-file:
- Microsoft.DataLakeStore/stable/2016-11-01/account.json
```

### Tag: package-2015-10-preview

These settings apply only when `--tag=package-2015-10-preview` is specified on the command line.

``` yaml $(tag) == 'package-2015-10-preview'
title: DataLakeStoreAccountManagementClient
description: DataLake Store Client
input-file:
- Microsoft.DataLakeStore/preview/2015-10-01-preview/account.json
```

## Suppression
``` yaml
directive:
  - suppress: TrackedResourceGetOperation
    reason: This is by design in that we return DataLakeStoreAccountBasic only for Account_List
    #where:
    #  - $.definitions.DataLakeStoreAccountBasic

  - suppress: TrackedResourcePatchOperation
    reason: DataLakeStoreAccountBasic is not independent and its purpose is for Account_List only.  PATCH is for DataLakeStoreAccount, which will effectively update DataLakeStoreAccountBasic
    #where:
    #  - $.definitions.DataLakeStoreAccountBasic
```

---
# Code Generation


## Swagger to SDK

This section describes what SDK should be generated by the automatic system.
This is not used by Autorest itself.

``` yaml $(swagger-to-sdk)
swagger-to-sdk:
  - repo: azure-sdk-for-python
  - repo: azure-sdk-for-java
  - repo: azure-sdk-for-go
  - repo: azure-sdk-for-node
  - repo: azure-sdk-for-ruby
    after_scripts:
      - bundle install && rake arm:regen_all_profiles['azure_mgmt_datalake_store']
```


## C#

These settings apply only when `--csharp` is specified on the command line.
Please also specify `--csharp-sdks-folder=<path to "SDKs" directory of your azure-sdk-for-net clone>`.

``` yaml $(csharp)
csharp:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  namespace: Microsoft.Azure.Management.DataLake.Store
  output-folder: $(csharp-sdks-folder)/DataLake.Store/Management.DataLake.Store/Generated
  clear-output-folder: true
```

## Python

These settings apply only when `--python` is specified on the command line.
Please also specify `--python-sdks-folder=<path to the root directory of your azure-sdk-for-python clone>`.
Use `--python-mode=update` if you already have a setup.py and just want to update the code itself.

``` yaml $(python)
python-mode: create
python:
  azure-arm: true
  license-header: MICROSOFT_MIT_NO_VERSION
  payload-flattening-threshold: 2
  namespace: azure.mgmt.datalake.store
  package-name: azure-mgmt-datalake-store
  clear-output-folder: true
```
``` yaml $(python) && $(python-mode) == 'update'
python:
  no-namespace-folders: true
  output-folder: $(python-sdks-folder)/azure-mgmt-datalake-store/azure/mgmt/datalake/store
```
``` yaml $(python) && $(python-mode) == 'create'
python:
  basic-setup-py: true
  output-folder: $(python-sdks-folder)/azure-mgmt-datalake-store
```


## Go

These settings apply only when `--go` is specified on the command line.

``` yaml $(go)
go:
  license-header: MICROSOFT_APACHE_NO_VERSION
  namespace: account
  clear-output-folder: true
```

### Go multi-api

``` yaml $(go) && $(multiapi)
batch:
  - tag: package-2016-11
  - tag: package-2015-10-preview
```

### Tag: package-2016-11 and go

These settings apply only when `--tag=package-2016-11 --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2016-11' && $(go)
output-folder: $(go-sdk-folder)/services/datalake/store/mgmt/2016-11-01/account
```

### Tag: package-2015-10-preview and go

These settings apply only when `--tag=package-2015-10-preview --go` is specified on the command line.
Please also specify `--go-sdk-folder=<path to the root directory of your azure-sdk-for-go clone>`.

``` yaml $(tag) == 'package-2015-10-preview' && $(go)
output-folder: $(go-sdk-folder)/services/preview/datalake/store/mgmt/2015-10-01-preview/account
```


## Java

These settings apply only when `--java` is specified on the command line.
Please also specify `--azure-libraries-for-java-folder=<path to the root directory of your azure-libraries-for-java clone>`.

``` yaml $(java)
java:
  azure-arm: true
  namespace: com.microsoft.azure.management.datalake.store
  license-header: MICROSOFT_MIT_NO_CODEGEN
  output-folder: $(azure-libraries-for-java-folder)/azure-mgmt-datalake/store
```

### Java multi-api

``` yaml $(java) && $(multiapi)
batch:
  - tag: package-2015-10-preview
  - tag: package-2016-11
```

### Tag: package-2015-10-preview and java

These settings apply only when `--tag=package-2015-10-preview --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2015-10-preview' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.datalakestore.v2015_10_01_preview
  output-folder: $(azure-libraries-for-java-folder)/datalakestore/resource-manager/v2015_10_01_preview
regenerate-manager: true
generate-interface: true
```

### Tag: package-2016-11 and java

These settings apply only when `--tag=package-2016-11 --java` is specified on the command line.
Please also specify `--azure-libraries-for-java=<path to the root directory of your azure-sdk-for-java clone>`.

``` yaml $(tag) == 'package-2016-11' && $(java) && $(multiapi)
java:
  namespace: com.microsoft.azure.management.datalakestore.v2016_11_01
  output-folder: $(azure-libraries-for-java-folder)/datalakestore/resource-manager/v2016_11_01
regenerate-manager: true
generate-interface: true
```


